==> chromium_108.0.5359.124.orig.tar.xz: chromium-108.0.5359.124/chrome/browser/android/compositor/layer/tab_handle_layer.h <==
// Copyright 2015 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_ANDROID_COMPOSITOR_LAYER_TAB_HANDLE_LAYER_H_
#define CHROME_BROWSER_ANDROID_COMPOSITOR_LAYER_TAB_HANDLE_LAYER_H_

#include "base/memory/raw_ptr.h"
#include "cc/layers/nine_patch_layer.h"
#include "cc/layers/solid_color_layer.h"
#include "cc/layers/ui_resource_layer.h"
#include "chrome/browser/android/compositor/layer/layer.h"
#include "ui/android/resources/resource_manager.h"

namespace cc {
class Layer;
class NinePatchLayer;
}

namespace ui {
class NinePatchResource;
}

namespace android {

class LayerTitleCache;

class TabHandleLayer : public Layer {
 public:
  static scoped_refptr<TabHandleLayer> Create(
      LayerTitleCache* layer_title_cache);

  TabHandleLayer(const TabHandleLayer&) = delete;
  TabHandleLayer& operator=(const TabHandleLayer&) = delete;

  void SetProperties(int id,
                     ui::Resource* close_button_resource,
                     ui::NinePatchResource* tab_handle_resource,
                     ui::NinePatchResource* tab_handle_outline_resource,
                     bool foreground,
                     bool close_pressed,
                     float toolbar_width,
                     float x,
                     float y,
                     float width,
                     float height,
                     float content_offset_x,
                     float close_button_alpha,
                     bool is_loading,
                     float spinner_rotation,
                     float brightness);
  scoped_refptr<cc::Layer> layer() override;

 protected:
  explicit TabHandleLayer(LayerTitleCache* layer_title_cache);
  ~TabHandleLayer() override;

 private:
  raw_ptr<LayerTitleCache> layer_title_cache_;

  scoped_refptr<cc::Layer> layer_;
  scoped_refptr<cc::UIResourceLayer> close_button_;
  scoped_refptr<cc::NinePatchLayer> decoration_tab_;
  scoped_refptr<cc::NinePatchLayer> tab_outline_;
  scoped_refptr<cc::Layer> title_layer_;

  float brightness_;
  bool foreground_;
};

}  // namespace android

#endif  // CHROME_BROWSER_ANDROID_COMPOSITOR_LAYER_TAB_HANDLE_LAYER_H_

==> chromium_111.0.5563.64.orig.tar.xz: chromium-111.0.5563.64/chrome/browser/android/compositor/layer/tab_handle_layer.h <==
// Copyright 2015 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_ANDROID_COMPOSITOR_LAYER_TAB_HANDLE_LAYER_H_
#define CHROME_BROWSER_ANDROID_COMPOSITOR_LAYER_TAB_HANDLE_LAYER_H_

#include "base/memory/raw_ptr.h"
#include "cc/layers/nine_patch_layer.h"
#include "cc/layers/solid_color_layer.h"
#include "cc/layers/ui_resource_layer.h"
#include "chrome/browser/android/compositor/layer/layer.h"
#include "ui/android/resources/resource_manager.h"

namespace cc {
class Layer;
class NinePatchLayer;
}

namespace ui {
class NinePatchResource;
}

namespace android {

class LayerTitleCache;

class TabHandleLayer : public Layer {
 public:
  static scoped_refptr<TabHandleLayer> Create(
      LayerTitleCache* layer_title_cache);

  TabHandleLayer(const TabHandleLayer&) = delete;
  TabHandleLayer& operator=(const TabHandleLayer&) = delete;

  void SetProperties(int id,
                     ui::Resource* close_button_resource,
                     ui::Resource* divider_resource,
                     ui::NinePatchResource* tab_handle_resource,
                     ui::NinePatchResource* tab_handle_outline_resource,
                     bool foreground,
                     bool close_pressed,
                     float toolbar_width,
                     float x,
                     float y,
                     float width,
                     float height,
                     float content_offset_x,
                     float content_offset_y,
                     float divider_offset_x,
                     float bottom_offset_y,
                     float close_button_padding,
                     float close_button_alpha,
                     bool is_start_divider_visible,
                     bool is_end_divider_visible,
                     bool is_loading,
                     float spinner_rotation,
                     float brightness,
                     float opacity,
                     bool is_tab_strip_redesign_enabled);
  scoped_refptr<cc::Layer> layer() override;

 protected:
  explicit TabHandleLayer(LayerTitleCache* layer_title_cache);
  ~TabHandleLayer() override;

 private:
  raw_ptr<LayerTitleCache> layer_title_cache_;

  scoped_refptr<cc::Layer> layer_;
  scoped_refptr<cc::Layer> tab_;
  scoped_refptr<cc::UIResourceLayer> close_button_;
  scoped_refptr<cc::UIResourceLayer> start_divider_;
  scoped_refptr<cc::UIResourceLayer> end_divider_;
  scoped_refptr<cc::NinePatchLayer> decoration_tab_;
  scoped_refptr<cc::NinePatchLayer> tab_outline_;
  scoped_refptr<cc::Layer> title_layer_;

  float brightness_;
  float opacity_;
  bool foreground_;
};

}  // namespace android

#endif  // CHROME_BROWSER_ANDROID_COMPOSITOR_LAYER_TAB_HANDLE_LAYER_H_
